@@ -1,8 +1,16 @@
 #' Merge tables
 #'
+#' @description
 #' Merge gtsummary tables, e.g. `tbl_regression`, `tbl_uvregression`, `tbl_stack`,
 #' `tbl_summary`, `tbl_svysummary`, etc.
 #'
+#' This function merges **like tables**.
+#' Generally, this means each of the tables being merged
+#' should have the same structure.
+#' When merging tables with different structures, rows may appear
+#' out of order.
+#' The ordering of rows can be updated with `modify_table_body(~dplyr::arrange(.x, ...))`.
+#'
 #' @param tbls (`list`)\cr
 #'   List of gtsummary objects to merge
 #' @param tab_spanner (`character`)\cr
@@ -17,6 +25,10 @@
 #'   `c(any_of(c("variable", "row_type", "var_label", "label"), cards::all_ard_groups())`.
 #'   Any column name included here that does not appear in all tables, will
 #'   be removed.
+#' @param tbl_ids (`character`)\cr
+#'   Optional character vector of IDs that will be assigned to the input tables.
+#'   The ID is assigned by assigning a name to the `tbls` list, which is
+#'   returned in `x$tbls`.
 #'
 #' @author Daniel D. Sjoberg
 #' @export
@@ -57,7 +69,7 @@
 #'
 #' tbl_merge(tbls = list(t3, t4)) %>%
 #'   modify_spanning_header(everything() ~ NA_character_)
-tbl_merge <- function(tbls, tab_spanner = NULL, merge_vars = NULL) {
+tbl_merge <- function(tbls, tab_spanner = NULL, merge_vars = NULL, tbl_ids = NULL) {
   set_cli_abort_call()
 
   # input checks ---------------------------------------------------------------
@@ -74,6 +86,10 @@ tbl_merge <- function(tbls, tab_spanner = NULL, merge_vars = NULL) {
     error_msg = "All objects in {.arg tbls} list must be class {.cls gtsummary}."
   )
   check_class(merge_vars, cls = "character", allow_empty = TRUE)
+  check_class(tbl_ids, cls = "character", allow_empty = TRUE)
+  if (!is_empty(tbl_ids)) {
+    check_identical_length(tbls, tbl_ids)
+  }
 
   if (!is_empty(tab_spanner) && !isFALSE(tab_spanner) && !is.character(tab_spanner)) {
     cli::cli_abort(
@@ -165,6 +181,11 @@ tbl_merge <- function(tbls, tab_spanner = NULL, merge_vars = NULL) {
 
   x <- .tbl_merge_update_table_styling(x = x, tbls = tbls, merge_vars = merge_vars)
 
+  # add tbl_ids, if specified --------------------------------------------------
+  if (!is_empty(tbl_ids)) {
+    names(x$tbls) <- tbl_ids
+  }
+
   # returning results ----------------------------------------------------------
   class(x) <- c("tbl_merge", "gtsummary")
   x
@@ -218,7 +239,9 @@ tbl_merge <- function(tbls, tab_spanner = NULL, merge_vars = NULL) {
             style_updated$rows <-
               map(
                 style_updated$rows,
-                ~ .rename_variables_in_expression(.x, i, tbls[[i]])
+                \(.x) {
+                  .rename_variables_in_expression(.x, i, tbls[[i]], merge_vars = merge_vars)
+                }
               )
           }
 
@@ -227,7 +250,7 @@ tbl_merge <- function(tbls, tab_spanner = NULL, merge_vars = NULL) {
             style_updated$pattern <-
               map_chr(
                 style_updated$pattern,
-                ~ .rename_variables_in_pattern(.x, i, tbls[[i]])
+                ~ .rename_variables_in_pattern(.x, i, tbls[[i]], merge_vars = merge_vars)
               )
           }
 
@@ -252,7 +275,8 @@ tbl_merge <- function(tbls, tab_spanner = NULL, merge_vars = NULL) {
         ~ .rename_variables_in_expression(
           rows = getElement(tbls, .x) |> getElement("table_styling") |> getElement(style_type),
           id = .x,
-          tbl = tbls[[.x]]
+          tbl = tbls[[.x]],
+          merge_vars = merge_vars
         )
       ) %>%
       reduce(.f = \(.x, .y) .x %||% .y)
@@ -261,7 +285,7 @@ tbl_merge <- function(tbls, tab_spanner = NULL, merge_vars = NULL) {
   x
 }
 
-.rename_variables_in_expression <- function(rows, id, tbl) {
+.rename_variables_in_expression <- function(rows, id, tbl, merge_vars) {
   # if NULL, return rows expression unmodified
   rows_evaluated <- eval_tidy(rows, data = tbl$table_body)
   if (is.null(rows_evaluated)) {
@@ -277,7 +301,7 @@ tbl_merge <- function(tbls, tab_spanner = NULL, merge_vars = NULL) {
     expr(~ !!expr) %>%
     eval() %>%
     all.vars() %>%
-    setdiff(c("label", "variable", "var_label", "row_type")) %>%
+    setdiff(merge_vars) %>%
     intersect(columns)
 
   # if no variables to rename, return rows unaltered
@@ -302,7 +326,7 @@ tbl_merge <- function(tbls, tab_spanner = NULL, merge_vars = NULL) {
   expr_renamed
 }
 
-.rename_variables_in_pattern <- function(pattern, id, tbl) {
+.rename_variables_in_pattern <- function(pattern, id, tbl, merge_vars) {
   # get all variable names in expression to be renamed
   columns <- tbl$table_styling$header$column
   var_list <-
@@ -310,7 +334,7 @@ tbl_merge <- function(tbls, tab_spanner = NULL, merge_vars = NULL) {
     map(~ str_remove_all(.x, pattern = "}", fixed = TRUE)) %>%
     map(~ str_remove_all(.x, pattern = "{", fixed = TRUE)) %>%
     unlist() %>%
-    setdiff(c("label", "variable", "var_label", "row_type")) %>%
+    setdiff(merge_vars) %>%
     intersect(columns)
 
   # if no variables to rename, return rows unaltered
