@@ -10,7 +10,6 @@
 
 # add_p.tbl_summary ------------------------------------------------------------
 add_p_test_t.test <- function(data, variable, by, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -25,7 +24,6 @@ add_p_test_t.test <- function(data, variable, by, test.args, conf.level = 0.95,
 }
 
 add_p_test_wilcox.test <- function(data, variable, by, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -49,7 +47,6 @@ add_p_test_wilcox.test <- function(data, variable, by, test.args, conf.level = 0
 
 
 add_p_test_mcnemar.test <- function(data, variable, by, group, test.args, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("adj.vars"), ...)
   check_length(group, 1L)
   warn_unbalanced_pairs(data, by, variable, group)
@@ -66,7 +63,6 @@ add_p_test_mcnemar.test <- function(data, variable, by, group, test.args, ...) {
 }
 
 add_p_test_mcnemar.test_wide <- function(data, variable, by, test.args, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -80,7 +76,6 @@ add_p_test_mcnemar.test_wide <- function(data, variable, by, test.args, ...) {
 }
 
 add_p_test_chisq.test <- function(data, variable, by, test.args, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -108,7 +103,6 @@ add_p_test_chisq.test.no.correct <- function(data, variable, by, test.args, ...)
 }
 
 add_p_test_mood.test <- function(data, variable, by, test.args, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -123,7 +117,6 @@ add_p_test_mood.test <- function(data, variable, by, test.args, ...) {
 
 
 add_p_test_kruskal.test <- function(data, variable, by, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars", "test.args"), ...)
 
   cardx::ard_stats_kruskal_test(
@@ -134,7 +127,6 @@ add_p_test_kruskal.test <- function(data, variable, by, ...) {
 }
 
 add_p_test_fisher.test <- function(data, variable, by, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -156,7 +148,6 @@ add_p_test_fisher.test <- function(data, variable, by, test.args, conf.level = 0
 }
 
 add_p_test_aov <- function(data, variable, by, ...) {
-  check_pkg_installed("cardx")
   cli::cli_warn(c(
     "The test {.val aov} in {.code add_p(test)} was deprecated in {.pkg gtsummary} 2.0.0.",
     i = "The same functionality is covered in {.val oneway.test} with argument `var.equal = TRUE`."
@@ -167,7 +158,6 @@ add_p_test_aov <- function(data, variable, by, ...) {
 }
 
 add_p_test_oneway.test <- function(data, variable, by, test.args, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -180,7 +170,6 @@ add_p_test_oneway.test <- function(data, variable, by, test.args, ...) {
 }
 
 add_p_test_lme4 <- function(data, variable, by, group, ...) {
-  check_pkg_installed("cardx")
   check_pkg_installed("lme4", ref = "cardx")
   check_empty(c("test.args", "adj.vars"), ...)
 
@@ -210,7 +199,6 @@ add_p_test_lme4 <- function(data, variable, by, group, ...) {
 
 
 add_p_tbl_summary_paired.t.test <- function(data, variable, by, group, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx")
   check_length(group, 1L)
   warn_unbalanced_pairs(data, by, variable, group)
   check_empty(c("adj.vars"), ...)
@@ -228,7 +216,6 @@ add_p_tbl_summary_paired.t.test <- function(data, variable, by, group, test.args
 }
 
 add_p_tbl_summary_paired.wilcox.test <- function(data, variable, by, group, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("adj.vars"), ...)
   check_length(group, 1L)
   warn_unbalanced_pairs(data, by, variable, group)
@@ -246,7 +233,6 @@ add_p_tbl_summary_paired.wilcox.test <- function(data, variable, by, group, test
 }
 
 add_p_test_prop.test <- function(data, variable, by, test.args, conf.level = 0.95, tbl, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("adj.vars", "group"), ...)
 
   # convert variable to lgl using the `value` argument
@@ -267,7 +253,6 @@ add_p_test_prop.test <- function(data, variable, by, test.args, conf.level = 0.9
 }
 
 add_p_test_ancova <- function(data, variable, by, adj.vars = NULL, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("group", "test.args"), ...)
   check_n_levels(data[[by]], 2L, message = "The {.arg by} column must have {.val {length}} levels.")
 
@@ -311,7 +296,6 @@ add_p_test_ancova <- function(data, variable, by, adj.vars = NULL, ...) {
 
 
 add_p_test_cohens_d <- function(data, variable, by, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -327,7 +311,6 @@ add_p_test_cohens_d <- function(data, variable, by, test.args, conf.level = 0.95
 }
 
 add_p_test_paired_cohens_d <- function(data, variable, by, test.args, group, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("adj.vars"), ...)
   check_length(group, 1L)
   warn_unbalanced_pairs(data, by, variable, group)
@@ -346,7 +329,6 @@ add_p_test_paired_cohens_d <- function(data, variable, by, test.args, group, con
 }
 
 add_p_test_hedges_g <- function(data, variable, by, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -362,7 +344,6 @@ add_p_test_hedges_g <- function(data, variable, by, test.args, conf.level = 0.95
 }
 
 add_p_test_paired_hedges_g <- function(data, variable, by, test.args, group, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("adj.vars"), ...)
   check_length(group, 1L)
   warn_unbalanced_pairs(data, by, variable, group)
@@ -381,7 +362,6 @@ add_p_test_paired_hedges_g <- function(data, variable, by, test.args, group, con
 }
 
 add_p_test_smd <- function(data, variable, by, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars", "test.args"), ...)
 
   cardx::ard_smd_smd(
@@ -394,7 +374,6 @@ add_p_test_smd <- function(data, variable, by, ...) {
 
 add_p_test_emmeans <- function(data, variable, by, adj.vars = NULL, conf.level = 0.95,
                                type, group = NULL, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("test.args"), ...)
 
   if (!is_empty(group)) check_pkg_installed("lme4", ref = "cardx")
@@ -470,7 +449,6 @@ add_p_test_emmeans <- function(data, variable, by, adj.vars = NULL, conf.level =
 }
 
 add_p_test_ancova_lme4 <- function(data, variable, by, group, conf.level = 0.95, adj.vars = NULL, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("test.args"), ...)
   check_length(group, 1L)
 
@@ -521,7 +499,6 @@ add_p_test_ancova_lme4 <- function(data, variable, by, group, conf.level = 0.95,
 
 # tbl_svysummary ---------------------------------------------------------------
 add_p_test_svy.t.test <- function(data, variable, by, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx")
   check_empty(c("test.args"), ...)
 
   cardx::ard_survey_svyttest(
@@ -536,7 +513,6 @@ add_p_test_svy.svyranktest <- function(data,
                                        variable,
                                        by,
                                        test = c("wilcoxon", "vanderWaerden", "median", "KruskalWallis"), ...) {
-  check_pkg_installed("cardx")
   check_empty(c("test.args"), ...)
   test <- arg_match(test)
 
@@ -554,7 +530,6 @@ add_p_test_svychisq.test <- function(data,
                                       by,
                                       statistic = c("F", "Chisq", "Wald", "adjWald", "lincom",
                                                     "saddlepoint", "wls-score"), ...) {
-  check_pkg_installed("cardx")
   check_empty(c("test.args"), ...)
   statistic <- arg_match(statistic)
 
@@ -638,7 +613,7 @@ extract_formula_data_call <- function(x) {
 }
 
 add_p_tbl_survfit_survdiff <- function(data, variable, test.args, ...) {
-  check_pkg_installed(c("cardx", "survival"))
+  check_pkg_installed("survival")
 
   # formula and data calls
   formula_data_call <-
@@ -662,7 +637,7 @@ add_p_tbl_survfit_petopeto_gehanwilcoxon <- function(data, variable, ...) {
 }
 
 add_p_tbl_survfit_coxph <- function(data, variable, test_type = c("log", "sc", "wald"), test.args, ...) {
-  check_pkg_installed(c("cardx", "survival", "broom"))
+  check_pkg_installed(c("survival", "broom"))
   test_type <- arg_match(test_type)
 
   # formula and data calls
