@@ -64,7 +64,8 @@ test_that("add_difference.tbl_summary(tests = 'emmeans')", {
     tbl1$cards$add_difference$ttdeath |>
       dplyr::select(
         -cards::all_ard_groups(),
-        -cards::all_ard_variables()
+        -cards::all_ard_variables(),
+        -fmt_fun
       ),
     cardx::ard_emmeans_mean_difference(
       data = trial,
@@ -74,8 +75,10 @@ test_that("add_difference.tbl_summary(tests = 'emmeans')", {
     ) |>
       dplyr::select(
         -cards::all_ard_groups(),
-        -cards::all_ard_variables()
-      )
+        -cards::all_ard_variables(),
+        -fmt_fun
+      ),
+    ignore_attr = TRUE
   )
 
   tbl2 <-
@@ -90,7 +93,8 @@ test_that("add_difference.tbl_summary(tests = 'emmeans')", {
     tbl2$cards$add_difference$ttdeath |>
       dplyr::select(
         -cards::all_ard_groups(),
-        -cards::all_ard_variables()
+        -cards::all_ard_variables(),
+        -fmt_fun
       ),
     cardx::ard_emmeans_mean_difference(
       data = trial,
@@ -101,8 +105,10 @@ test_that("add_difference.tbl_summary(tests = 'emmeans')", {
     ) |>
       dplyr::select(
         -cards::all_ard_groups(),
-        -cards::all_ard_variables()
-      )
+        -cards::all_ard_variables(),
+        -fmt_fun
+      ),
+    ignore_attr = TRUE
   )
 
   tbl3 <-
@@ -117,7 +123,8 @@ test_that("add_difference.tbl_summary(tests = 'emmeans')", {
     tbl3$cards$add_difference$response |>
       dplyr::select(
         -cards::all_ard_groups(),
-        -cards::all_ard_variables()
+        -cards::all_ard_variables(),
+        -fmt_fun
       ),
     cardx::ard_emmeans_mean_difference(
       data = trial,
@@ -128,8 +135,10 @@ test_that("add_difference.tbl_summary(tests = 'emmeans')", {
     ) |>
       dplyr::select(
         -cards::all_ard_groups(),
-        -cards::all_ard_variables()
-      )
+        -cards::all_ard_variables(),
+        -fmt_fun
+      ),
+    ignore_attr = TRUE
   )
 })
 
@@ -603,8 +612,8 @@ test_that("add_difference.tbl_summary() with emmeans()", {
 })
 
 test_that("ordering in add_difference.tbl_summary() with paired tests", {
-  expect_snapshot(
-    mtcars |>
+  expect_snapshot({
+    tbl <- mtcars |>
       mutate(
         .by = am,
         id = dplyr::row_number(),
@@ -614,12 +623,14 @@ test_that("ordering in add_difference.tbl_summary() with paired tests", {
         by = am,
         include = mpg
       ) |>
-      add_difference(test = ~"paired.t.test", group = id) |>
+      add_difference(test = ~"paired.t.test", group = id)
+
+    tbl |>
       modify_column_hide(all_stat_cols()) |>
       as.data.frame()
-  )
-  expect_snapshot(
-    mtcars |>
+  })
+  expect_snapshot({
+    tbl <- mtcars |>
       mutate(
         .by = am,
         id = dplyr::row_number(),
@@ -629,10 +640,12 @@ test_that("ordering in add_difference.tbl_summary() with paired tests", {
         by = am,
         include = mpg
       ) |>
-      add_difference(test = ~"paired.t.test", group = id) |>
+      add_difference(test = ~"paired.t.test", group = id)
+
+    tbl |>
       modify_column_hide(all_stat_cols()) |>
       as.data.frame()
-  )
+  })
 })
 
 test_that("addressing GH #2165: Non-logical dichotomous comparisons using prop.test()", {
@@ -648,11 +661,13 @@ test_that("addressing GH #2165: Non-logical dichotomous comparisons using prop.t
       gather_ard() |>
       getElement("add_difference") |>
       getElement("response") |>
-      dplyr::select(-"fmt_fn"),
+      dplyr::select(-"fmt_fun"),
     trial |>
       dplyr::mutate(response = response == 1) |>
       cardx::ard_stats_prop_test(by = trt, variable = response) |>
-      dplyr::select(-"fmt_fn")
+      cards::replace_null_statistic() |>
+      dplyr::select(-"fmt_fun"),
+    ignore_attr = TRUE
   )
 
   # check when the value presented is the opposite (FALSE)
@@ -668,11 +683,13 @@ test_that("addressing GH #2165: Non-logical dichotomous comparisons using prop.t
       gather_ard() |>
       getElement("add_difference") |>
       getElement("response") |>
-      dplyr::select(-"fmt_fn"),
+      dplyr::select(-"fmt_fun"),
     trial |>
       dplyr::mutate(response = response == 0) |>
       cardx::ard_stats_prop_test(by = trt, variable = response) |>
-      dplyr::select(-"fmt_fn")
+      cards::replace_null_statistic() |>
+      dplyr::select(-"fmt_fun"),
+    ignore_attr = TRUE
   )
 
   # check results when variable has >2 levels
@@ -687,11 +704,13 @@ test_that("addressing GH #2165: Non-logical dichotomous comparisons using prop.t
       gather_ard() |>
       getElement("add_difference") |>
       getElement("grade") |>
-      dplyr::select(-"fmt_fn"),
+      dplyr::select(-"fmt_fun"),
     trial |>
       dplyr::mutate(grade = grade == "I") |>
       cardx::ard_stats_prop_test(by = trt, variable = grade) |>
-      dplyr::select(-"fmt_fn")
+      cards::replace_null_statistic() |>
+      dplyr::select(-"fmt_fun"),
+    ignore_attr = TRUE
   )
 })
 
