@@ -3,8 +3,8 @@ skip_if_not(is_pkg_installed("survey"))
 
 tbl_ard <- cards::ard_stack(
   data = cards::ADSL |> dplyr::mutate(AGEGR1 = factor(AGEGR1, levels = c("<65", "65-80", ">80"))),
-  cards::ard_categorical(variables = "AGEGR1"),
-  cards::ard_continuous(variables = "AGE"),
+  cards::ard_tabulate(variables = "AGEGR1"),
+  cards::ard_summary(variables = "AGE"),
   .attributes = TRUE,
   .missing = TRUE,
   .total_n = TRUE
@@ -40,8 +40,8 @@ test_that("add_stat_label(label) standard use", {
   expect_snapshot(
     cards::ard_stack(
       data = cards::ADSL,
-      cards::ard_categorical(variables = "AGEGR1"),
-      cards::ard_continuous(variables = "AGE"),
+      cards::ard_tabulate(variables = "AGEGR1"),
+      cards::ard_summary(variables = "AGE"),
       .attributes = TRUE,
       .missing = TRUE,
       .total_n = TRUE
@@ -60,8 +60,8 @@ test_that("add_stat_label(label) messaging", {
     error = TRUE,
     cards::ard_stack(
       data = cards::ADSL,
-      cards::ard_categorical(variables = "AGEGR1"),
-      cards::ard_continuous(variables = "AGE"),
+      cards::ard_tabulate(variables = "AGEGR1"),
+      cards::ard_summary(variables = "AGE"),
       .attributes = TRUE,
       .missing = TRUE,
       .total_n = TRUE
@@ -77,8 +77,8 @@ test_that("add_stat_label(label) messaging", {
     error = TRUE,
     cards::ard_stack(
       data = cards::ADSL,
-      cards::ard_categorical(variables = "AGEGR1"),
-      cards::ard_continuous(variables = "AGE"),
+      cards::ard_tabulate(variables = "AGEGR1"),
+      cards::ard_summary(variables = "AGE"),
       .attributes = TRUE,
       .missing = TRUE,
       .total_n = TRUE
@@ -95,8 +95,8 @@ test_that("add_stat_label() messaging", {
   expect_snapshot(
     cards::ard_stack(
       data = cards::ADSL,
-      cards::ard_categorical(variables = "AGEGR1"),
-      cards::ard_continuous(variables = "AGE"),
+      cards::ard_tabulate(variables = "AGEGR1"),
+      cards::ard_summary(variables = "AGE"),
       .attributes = TRUE,
       .missing = TRUE,
       .total_n = TRUE
