@@ -120,7 +120,7 @@ test_that("modify_spanning_header(text_interpret) works", {
 })
 
 test_that("modify_spanning_header() works with tbl_svysummary()", {
-  skip_if_not(is_pkg_installed(c("survey", "cardx")))
+  skip_if_not(is_pkg_installed("survey"))
 
   expect_equal(
     survey::svydesign(~1, data = as.data.frame(Titanic), weights = ~Freq) |>
@@ -160,7 +160,7 @@ test_that("modify_spanning_header() works with tbl_cross()", {
 })
 
 test_that("modify_spanning_header() works with tbl_regression()", {
-  skip_if_not(is_pkg_installed(c("cardx", "broom.helpers")))
+  skip_if_not(is_pkg_installed("broom.helpers"))
 
   expect_equal(
     glm(response ~ age + grade, trial, family = binomial()) |>
@@ -174,7 +174,7 @@ test_that("modify_spanning_header() works with tbl_regression()", {
 })
 
 test_that("modify_spanning_header() works with tbl_uvregression()", {
-  skip_if_not(is_pkg_installed(c("cardx", "broom.helpers")))
+  skip_if_not(is_pkg_installed("broom.helpers"))
   expect_equal(
     tbl_uvregression(trial, method = glm, y = response, method.args = list(family = binomial),
                      exponentiate = TRUE, include = c("age", "grade")) |>
