@@ -11,6 +11,14 @@ test_that("style_percent() works", {
     c(NA, "0%", "<0.01%", "0.01%", "0.50%", "1.00%", "10.0%", "45.4%", "99.0%", "145.0%")
   )
 
+  expect_equal(
+    style_percent(NA, na = "NE"),
+    "NE"
+  )
+  expect_equal(
+    style_percent(c(NA, -1, NA, 1), na = "NE", prefix = "*", suffix = "*"),
+    c("NE", NA, "NE", "*100*")
+  )
   vec2 <- c(one = 0.99, two = 0.0005)
   expect_equal(
     attributes(vec2),
