@@ -600,3 +600,66 @@ test_that("tbl_svysummary() default fmt fn", {
     "11 (5.5%)"
   )
 })
+
+# Fix for missing counts <1 in #2229
+test_that("tbl_svysummary() default fmt fn", {
+  expect_equal(
+    dplyr::tribble(
+      ~category,  ~success, ~weight,
+      "A",        TRUE,     2,
+      "A",        FALSE,    1,
+      "A",        NA,       0.5
+    ) |>
+      survey::svydesign(data = _, id = ~1, weights = ~weight) |>
+      tbl_svysummary(
+        include = success,
+        by = category
+      ) |>
+      getElement("table_body") |>
+      dplyr::filter(row_type == "missing") |>
+      dplyr::pull("stat_1"),
+    "1"
+  )
+})
+
+# missing values handled correctly
+# addressed https://stackoverflow.com/questions/79673577
+test_that("tbl_svysummary() missing `by` handling", {
+  database <- data.frame(
+    INDIV_AGE = rnorm(100, mean = 50, sd = 4),
+    INDIV_GENDER = rbinom(n = 100, size=1, prob = 0.6),
+    poids = rnorm(100, mean = 2, sd = 0.8)
+  )
+  attr(database$INDIV_AGE, "label") <- "Subject Age"
+
+  # no errors and proper messaging
+  expect_snapshot(
+    tbl <-
+      survey::svydesign(
+        id = ~1,
+        weights = ~poids,
+        data =
+          database |>
+          dplyr::mutate(INDIV_GENDER = ifelse(dplyr::row_number() == 1L, NA, INDIV_GENDER))
+      ) |>
+      tbl_svysummary(by = "INDIV_GENDER")
+  )
+
+  # ensure results are the same if row is entirely removed
+  expect_equal(
+    as.data.frame(tbl),
+    survey::svydesign(
+      id = ~1,
+      weights = ~poids,
+      data = database |> dplyr::filter(!dplyr::row_number() == 1L)
+    ) |>
+      tbl_svysummary(by = "INDIV_GENDER") |>
+      as.data.frame()
+  )
+
+  # check the variable label has been retained
+  expect_equal(
+    tbl$table_body$label[1],
+    "Subject Age"
+  )
+})
