@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed(c("broom.helpers", "broom", "survival", "survey"), reference_pkg = "gtsummary"))
+skip_if_not(is_pkg_installed(c("broom.helpers", "broom", "survival", "survey")))
 
 test_that("tbl_uvregression(x)", {
   expect_silent(
@@ -81,7 +81,7 @@ test_that("tbl_uvregression(method.args)", {
   )
 
   # check with NSE argument
-  expect_silent(
+  expect_error(
     tbl2 <-
       tbl_uvregression(
         trial,
@@ -89,7 +89,8 @@ test_that("tbl_uvregression(method.args)", {
         method = survival::coxph,
         method.args = list(id = response),
         include = c(age, trt)
-      )
+      ),
+    NA
   )
   # check models are the same
   expect_equal(
@@ -223,6 +224,20 @@ test_that("tbl_uvregression(include)", {
     ),
     "The `include` argument cannot be empty"
   )
+
+  # ensure non-syntactic names work in the `include` variables
+  expect_snapshot(
+    mtcars |>
+      dplyr::select(`M P G` = mpg, hp) |>
+      tbl_uvregression(y = hp, method = lm) |>
+      as.data.frame()
+  )
+  expect_snapshot(
+    mtcars |>
+      dplyr::select(`M P G` = mpg, hp) |>
+      tbl_uvregression(x = hp, method = lm) |>
+      as.data.frame()
+  )
 })
 
 test_that("tbl_uvregression(tidy_fun)", {
